@@ -1,6 +1,6 @@
 package App::ansicolumn;
 
-our $VERSION = "1.45";
+our $VERSION = "1.46";
 
 use v5.14;
 use warnings;
@@ -14,6 +14,7 @@ Configure qw(bundling);
 
 use Data::Dumper;
 use List::Util qw(max sum min);
+use Clone qw(clone);
 use Text::ANSI::Fold qw(ansi_fold);
 use Text::ANSI::Fold::Util qw(ansi_width);
 use Text::ANSI::Printf qw(ansi_printf ansi_sprintf);
@@ -36,7 +37,7 @@ use Getopt::EX::Hashed 1.05; {
     has width               => ' =s w c  ' ;
     has fillrows            => '    x    ' ;
     has table               => '    t    ' ;
-    has table_columns_limit => ' =i l    ' , default => 0 ;
+    has table_columns_limit => ' =i l    ' , default => -1 ;
     has table_align         => ' !  A    ' ;
     has table_tabs          => ' +  T    ' ;
     has table_right         => ' =s R    ' , default => '' ;
@@ -362,15 +363,14 @@ sub nup_out {
     my @files = @_;
     my $max_length = max map { $_->{length} } @files;
     $obj->set_horizontal($max_length);
-    my $reset = do { my @o = %$obj; sub { %$obj = @o } };
     for my $file (@files) {
 	my $data = $file->{data};
 	next if @$data == 0;
-	$obj->set_contents($file)
+	clone($obj)
+	    ->set_contents($file)
 	    ->set_vertical($data)
 	    ->set_layout($data)
 	    ->page_out(@$data);
-	$reset->();
     }
     return $obj;
 }
@@ -534,7 +534,8 @@ sub table_out {
     return unless @_;
     my $split = do {
 	if ($obj->separator eq ' ') {
-	    $obj->ignore_space ? ' ' : qr/\s+/;
+	    # /\s+/a does not work as expected, maybe perl's bug
+	    $obj->ignore_space ? ' ' : qr/\s{1,9999}/a;
 	} elsif ($obj->regex_sep) {
 	    qr($obj->{separator});
 	} else {
