@@ -185,6 +185,19 @@ my %template = (
 		    "▟" ],
 	bottom =>   "▄",
     },
+    ladder => {
+	top    =>    "─",
+	bottom =>    "─",
+	left   => [ ""  ,
+		    ""  ,
+		    "" ],
+	center => [ "┬─"  ,
+		    "│ "  ,
+		    "┴─" ],
+	right  => [ ""   ,
+		    ""   ,
+		    ""  ],
+    },
     frame => {
 	top    =>    "─",
 	bottom =>    "─",
@@ -457,7 +470,7 @@ my %template = (
 
 use Clone qw(clone);
 
-for my $style (qw(line vbar hline bottom_line box dash_box shadow_box frame dash_frame page_frame comb rake mesh
+for my $style (qw(line vbar hline bottom_line box dash_box shadow_box ladder frame dash_frame page_frame comb rake mesh
 		  dumbbell ribbon)) {
     $template{$style} // next;
     my $new = $template{"heavy_$style"} = clone $template{$style};
